#
# spec file for package ghc-foundation
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name foundation
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.0.23
Release:        lp151.1.2
Summary:        Alternative prelude with batteries and no dependencies
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-basement-devel
BuildRequires:  ghc-rpm-macros

%description
A custom prelude with no dependencies apart from base.

This package has the following goals:

* provide a base like sets of modules that provide a consistent set of features
and bugfixes across multiple versions of GHC (unlike base).

* provide a better and more efficient prelude than base's prelude.

* be self-sufficient: no external dependencies apart from base.

* provide better data-types: packed unicode string by default, arrays.

* Better numerical classes that better represent mathematical thing (No more
all-in-one Num).

* Better I/O system with less Lazy IO

* Usual partial functions distinguished through type system.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal
echo > Setup.hs 'import Distribution.Simple'
echo >>Setup.hs 'main = defaultMain'

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files

%changelog
* Thu Feb  7 2019 psimons@suse.com
- Update foundation to version 0.0.23.
  Upstream does not provide a change log file.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Tue Aug  7 2018 psimons@suse.com
- Update Cabal build information to support pre-8.x compilers.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update foundation to version 0.0.21.
  Upstream has removed the change log file they used to maintain
  before from the distribution tarball.
* Mon May 14 2018 psimons@suse.com
- Update foundation to version 0.0.20.
  * Reduce algorithm duplication between native and foreign backend
  * Improve Unicode cases algorithm and increase testing
  * Add CSV Builder
  * Add a BitOps & FiniteBitOps classes to have better types than the Data.Bits.Bits class
  * Improve BlockN operations
  * Improve ListN operations
  * Allow compilation with gauge 0.1
  * Add support for [haskell-ci](https://github.com/vincenthz/haskell-ci)
  * Add Block, UArray, String Builder
  * Improve concat for Block andd UArray
  * Add unicode case mapping
  * Re-add compatibility with ghc 7.8
  * Add missing lowlevel Block functionality
  * Cleanup UArray to use more functions from Block
  * Push Xoroshiro down to basement
  * Add instances for foundation's numerical classes for C types
  * Update benchmarks to gauge 0.2.0
  * Add documentation to some block & uarray functions
  * Add Terminal capabilities: ANSI Escape, UTF8 codepage initialization, get dimensions
  * Checks: Output now has colors
  * Hashable: Add Word128 & Word256 & Boxed Array instances
  * Semigroup: Compatibility with GHC 8.4
  * Drop criterion for benchmark, now use Gauge
  * Remove more UnboxedTuples from Foundation for easier loading with bytecode interpreter
  * Reduce overhead of profiling common primitive operation like size and offset addition by
    preventing auto-caf in abstraction module
  * Optimise UTF8 validation
  * Optimise String toList (allow fusion)
  * Optimise String reversal
  * Merge different version of lowlevel array algorithms with one backed by a class.
  * Zn64/Zn : Add Num, Additive, Subtractive, NormalForm, Arbitrary instances
  * Re-organize type sized structure and add UVect and Vect
  * Cleanup constraint in ListN, and add couple of combinators
  * Add ExceptT
  * Add some exception combinators (try,finally) that works with foundation classes.
  * Tidy mutable algorithm for sorting removing redundant code
  * Add primitive to convert Double/Float to Word64/Word32
  * Cleanup withPtr / getAddr code to be safer
  * Add Bits instance for Natural compat with 7.8
  * Add bounded Natural (Zn & Zn64)
  * Add Word128 and Word256
  * Add From/Into type class
  * Add breakEnd, spanEnd, revFindIndex
  * Improve arrays sorting
  * Add arrays fromListN implementation
  * Add arrays convertion primitive
  * Cleanup API
  * Implement unsnoc
  * Improve random generation with XorShift
  * Improve ghc 8.2 support (warning removals)
  * Remove dependency on QuickCheck
  * Split lowlevel modules into basement package
  * Fix compilation with musl
  * Improve native array safety when using through pointer
  * remove foldText
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Tue Jul 11 2017 psimons@suse.com
- Update to version 0.0.13.
* Sun Jun 25 2017 psimons@suse.com
- Update to version 0.0.12.
* Mon Jun 19 2017 psimons@suse.com
- Update to version 0.0.11.
* Mon Jun 12 2017 psimons@suse.com
- Update to version 0.0.10.
* Thu May 18 2017 psimons@suse.com
- Update to version 0.0.9 with cabal2obs.
* Wed May  3 2017 psimons@suse.com
- Update to version 0.0.8 revision 1 with cabal2obs.
* Mon Apr 24 2017 psimons@suse.com
- Update to version 0.0.7 revision 1 with cabal2obs.
* Sun Apr  9 2017 psimons@suse.com
- Update to version 0.0.6 with cabal2obs.
* Tue Apr  4 2017 psimons@suse.com
- Update to version 0.0.4 revision 3 with cabal2obs.
